pub unsafe extern "C" fn rcl_context_get_init_options(
context: *mut rcl_context_t
) -> *const rcl_init_options_tExpand description
Return the init options used during initialization for this context.
pub unsafe extern "C" fn rcl_context_get_init_options(
context: *mut rcl_context_t
) -> *const rcl_init_options_tReturn the init options used during initialization for this context.