pub unsafe extern "C" fn rcl_context_get_instance_id(
context: *mut rcl_context_t
) -> rcl_context_instance_id_tExpand description
Returns an unsigned integer that is unique to the given context, or 0 if invalid.
pub unsafe extern "C" fn rcl_context_get_instance_id(
context: *mut rcl_context_t
) -> rcl_context_instance_id_tReturns an unsigned integer that is unique to the given context, or 0 if invalid.