pub unsafe extern "C" fn rcl_context_is_valid(
context: *mut rcl_context_t
) -> boolExpand description
Return true if the given context is currently valid, otherwise false.
pub unsafe extern "C" fn rcl_context_is_valid(
context: *mut rcl_context_t
) -> boolReturn true if the given context is currently valid, otherwise false.